@@ -21,12 +21,8 @@ class Config:
     bn_momentum: float = 0.001
     amp: bool = False
     clip: float = 0
-    net: str = "WideResNet"
+    net: str = "wrn_28_2"
     net_from_name: bool = False
-    depth: int = 28
-    widen_factor: int = 2
-    leaky_slope: float = 0.1
-    dropout: float = 0.0
     dataset: str = "custom"
     train_sampler: str = "RandomSampler"
     num_classes: int = 0
