@@ -15,10 +15,10 @@ import torch.backends.cudnn as cudnn
 from torchvision import transforms
 
 from labelshift.lse.config import Config
-from labelshift.model import ModelTrainer
+from labelshift.trainer import ModelTrainer
 from labelshift.get_method import get_lse_methods
 from labelshift.datasets import get_data_loader, BasicDataset, ResampleDataset, ResampleDataset
-from labelshift.utils import net_builder, get_optimizer, get_cosine_schedule_with_warmup, labels_to_dist, over_write_args_from_dict
+from labelshift.utils import get_net_builder, get_optimizer, get_cosine_schedule_with_warmup, labels_to_dist, over_write_args_from_dict
 
 
 class LSE:
@@ -62,27 +62,16 @@ class LSE:
 
         cudnn.benchmark = True
 
-        _net_builder = net_builder(
-            self.cfg.net,
-            self.cfg.net_from_name,
-            {
-                "first_stride": 2 if "stl" in self.cfg.dataset else 1,
-                "depth": self.cfg.depth,
-                "widen_factor": self.cfg.widen_factor,
-                "leaky_slope": self.cfg.leaky_slope,
-                "bn_momentum": self.cfg.bn_momentum,
-                "dropRate": self.cfg.dropout,
-                "use_embed": False,
-            },
-        )
-        print()
+        net_builder = get_net_builder(self.cfg.net, self.cfg.net_from_name)
 
         # Construct Dataset & DataLoader
-        lb_dset = ResampleDataset(lb_data, lb_targets, self.cfg.num_classes, train_transform, test_transform, onehot=False, seed=self.cfg.seed)
+        lb_dset = ResampleDataset(
+            lb_data, lb_targets, self.cfg.num_classes, train_transform, test_transform, onehot=False, seed=self.cfg.seed
+        )
 
         for idx, train_lb_dset, val_lb_dset in lb_dset.resample(self.cfg.num_val_per_class, self.cfg.num_ensemble):
-            print(f"Training [{idx}/{self.cfg.num_ensemble}] Model")
-            model = ModelTrainer(_net_builder, self.cfg.num_classes, num_eval_iter=self.cfg.num_eval_iter, ema_m=self.cfg.ema_m)
+            print(f"\nTraining [{idx}/{self.cfg.num_ensemble}] Model")
+            model = ModelTrainer(net_builder, self.cfg.num_classes, num_eval_iter=self.cfg.num_eval_iter, ema_m=self.cfg.ema_m)
             # SET Optimizer & LR Scheduler
             ## construct SGD and cosine lr scheduler
             optimizer = get_optimizer(model.model, self.cfg.optim, self.cfg.lr, self.cfg.momentum, self.cfg.weight_decay)
@@ -134,13 +123,12 @@ class LSE:
                 logits = {"val_logits": raw_val_outputs, "val_targets": val_targets}
                 if self.cfg.save_model:
                     torch.save(logits, save_val_logits_path)
-            print()
 
         random.setstate(random_state)
         np.random.set_state(np_random_state)
         torch.random.set_rng_state(torch_random_state)
 
-        logging.warning("Training is FINISHED\n")
+        logging.warning("\nTraining is FINISHED\n")
 
     def pre_check(self):
         if not torch.cuda.is_available():
@@ -185,24 +173,11 @@ class LSE:
         return estimations
 
     def get_logits(self, ulb_dset):
-        _net_builder = net_builder(
-            self.cfg.net,
-            self.cfg.net_from_name,
-            {
-                "first_stride": 2 if "stl" in self.cfg.dataset else 1,
-                "depth": self.cfg.depth,
-                "widen_factor": self.cfg.widen_factor,
-                "leaky_slope": self.cfg.leaky_slope,
-                "bn_momentum": self.cfg.bn_momentum,
-                "dropRate": self.cfg.dropout,
-                "use_embed": False,
-            },
-            verbose=False,
-        )
+        net_builder = get_net_builder(self.cfg.net, self.cfg.net_from_name)
 
         logits = {"val_logits": [], "val_targets": [], "ulb_logits": []}
         ulb_loader = get_data_loader(ulb_dset, self.cfg.eval_batch_size, num_workers=self.cfg.num_workers, drop_last=False)
-        model = ModelTrainer(_net_builder, self.cfg.num_classes, num_eval_iter=self.cfg.num_eval_iter, ema_m=self.cfg.ema_m)
+        model = ModelTrainer(net_builder, self.cfg.num_classes, num_eval_iter=self.cfg.num_eval_iter, ema_m=self.cfg.ema_m)
 
         if self.cfg.gpu is not None:
             torch.cuda.set_device(self.cfg.gpu)
